/**
* Fascade class providing a full featured circuit editor containing an editable area and tools
*/
function CircuitEditor(
    parentNode      // Node whoose last child the editor should be
) {
    this.node = createHtml('div', parentNode);
    this.btnBar = new BtnBar(this.node);
    this.controller = new ControllerCircuitDisplay(createHtml('div', this.node, { style: 'overflow:auto' }));
    this.controller.editingMode = EditingModes[6];/*!*/
    this._addBtns();
}

/** Container for editor's DOM */
CircuitEditor.prototype.node = null;

/** Button bar */
CircuitEditor.prototype.btnBar = null;

/** Circuit */
CircuitEditor.prototype.controller = null;

/** Mapping of editing mode and button */
CircuitEditor.prototype._arrModeBtns = [];

/** Initial circuit used for resets (serialized string) */
CircuitEditor.prototype.initialData = '0';

/**
* Highlight only active editing mode
* @return undefined
*/
CircuitEditor.prototype.updateModeBtns = function() {
    this._arrModeBtns.forEach(({btn, mode}) => {btn.selected = (mode == this.controller.editingMode)});
}

/**
* Add buttons to menu bar
* @return undefined
*/
CircuitEditor.prototype._addBtns = function() {
    const objBtnBar = this.btnBar;
    const circuitcontroller = this.controller;
    const self = this;
    this._addBtnFile();
    this.btnBar.add([ true ]);
    this._arrModeBtns = EditingModes.slice(1).map(function(mode, index) {
        var btn = new BtnBarBtn(objBtnBar, mode.desc, mode.className, mode.className ? false : true);
        if (mode.title)
            btn.title = mode.title;
        btn.onclick = function() { circuitcontroller.editingMode = mode; self.updateModeBtns(); };
        if (index == 3) objBtnBar.add([ true ]);
        return { mode, btn };
    });
    this.updateModeBtns();
}

/**
* Add a file button to menu bar
* @return undefined
*/
CircuitEditor.prototype._addBtnFile = function() {
    const self = this;
    (new BtnBarBtn(this.btnBar, 'Datei', 'btn_file', true)).onclick = (function() {
        const objBubble = this.objBtnBar.showBubble();
        const submenu = new BtnBar(objBubble.node, true, objBubble, true);
        submenu.add([
            { label: 'Zurücksetzen', className: 'btn_new', title: 'Alle Änderungen verwerfen und den zu Beginn angezeigten Schaltplan wiederherstellen', onclick: () => self.setData(self.initialData) },
            { label: 'Öffnen', className: 'btn_open', title: 'Als Datei gespeicherten Schaltplan öffnen', onclick: () => {
                let input = createHtml('input', document.body, {
                    type: 'file',
                    accept: 'image/svg+xml',
                    style: 'position:absolute;left:0;top:0;opacity:0;visibility:hidden'
                });
                input.addEventListener('change', (ev) => {
                    const curFiles = input.files;
                    if (!curFiles.length)
                        return;
                    self.loadFromFile(curFiles[0]);
                });
                input.click();
                input.parentNode.removeChild(input);
            } },
            { label: 'Speichern', className: 'btn_save', title: 'Schaltplan als lokale Datei speichern', onclick: () => {
                new SaveForm(self.btnBar, self.controller.circuit, self.controller.scale);
                return true;
            } },
            { label: 'Zentrieren', title: 'Schaltplan in die Mitte des Bearbeitungsbereichs verschieben', onclick: () => { self.controller.resetOffset(); self.controller.updateSvg() } },
            { label: 'Zurück', className: 'btn_close', title: 'Dieses Menü schließen' }
        ]);
    });
}

/**
* Replace circuit with circuit described by a serialized string
* @return undefined
*/
CircuitEditor.prototype.setData = function(
    data,           // Serialized string
    boolIsDefault   // Optional: Use circuit described by data as initial circuit for resets?
) {
    this.controller.circuit.unserialize(data);
    if (boolIsDefault)
        this.initialData = data;
}

/**
* Replace circuit by circuit described by file (or display error if there is no circuit data)
* @return undefined
*/
CircuitEditor.prototype.loadFromFile = function(
    file,           // File object containing data to load
    boolIsDefault   // Optional: Use circuit described by data as initial circuit for resets?
) {
    const objReader = new FileReader();
    const self = this;
    objReader.addEventListener('load', function() {
        const oReq = new XMLHttpRequest();
        oReq.addEventListener("load", function() {
            const svg = oReq.responseXML;
            const dataNodes = svg.getElementsByTagNameNS('https://www.roith-unterrichtet.de', 'circuitdata');
            if (dataNodes.length)
                self.setData(dataNodes[0].textContent, boolIsDefault);
            else
                alert('Laden fehlgeschlagen: Datei enthält keine maschinenlesbaren Schaltplandaten.');
        });
        oReq.open("GET", objReader.result);
        oReq.send();
    });
    objReader.readAsDataURL(file);
}
