/**
* Builds meshes for ModelCircuit instance
*/
function CircuitMeshBuilder(
    circuit         // ModelCircuit instance containing circuit to build meshes from
) {
    Object.defineProperty(this, 'circuit', { enumerable: true, value: circuit, writeable: false });
    this._gridpointhash = GridPointHasher.create(circuit);
}

/** ModelCircuit instance containing circuit to build meshes from */
CircuitMeshBuilder.prototype.circuit = null;

/** Object used to calculate grid point's ids */
CircuitMeshBuilder.prototype._gridpointhash = null;

/**
* Build all meshes starting with part
* @return Array     Created CircuitMesh instances
*/
CircuitMeshBuilder.prototype.buildMeshes = function(
    part,           // CircuitPart instance to start with
    keepIncomplete  // Optional: Keep discontinued meshes
) {
    const incomplete = [ new CircuitMesh(part) ];
    const complete = [];
    while (incomplete.length) {
        const mesh = incomplete.pop();
        const currentGridPoint = mesh.getOpenEnd();
        if (!currentGridPoint) {
            complete.push(mesh);
            continue;
        }
        const branches = this.circuit.getPartsConnectedTo(currentGridPoint.x, currentGridPoint.y);
        const newMeshes = branches.map(part => {
            const m = mesh.clone();
            return m.add(part) ? m : null
        }).filter(m => m);
        if (newMeshes.length)
            newMeshes.forEach(mesh => incomplete.push(mesh));
        else if (keepIncomplete && (branches.length == 1))
            complete.push(mesh);
    }
    return complete;
}
