/**
* A single component in the mesh of a circuit
*/
function CircuitMeshPart(
    circuitpart,        // CircuitPart instance that represents this component within the circuit
    secondaryFirst      // Optional: Is (in mesh direction) the secondary connection of the CircuitPart the first connection to reach?
) {
    Object.defineProperty(this, 'part', { enumerable: true, value: circuitpart, writeable: false });
    if ((secondaryFirst !== undefined) && circuitpart.isDifferentConnectors() && (secondaryFirst != circuitpart.isFlipped))
        this.isSecondaryFirst = true;
}

/** CircuitPart instance that represents this component within the circuit */
CircuitMeshPart.prototype.part = null;

/** Is (in mesh direction) the secondary connection of the CircuitComponent the first connection to reach? (Only set to true if connections are electrical different!) */
CircuitMeshPart.prototype.isSecondaryFirst = false;

/** Corresponding CircuitComponent instance */
Object.defineProperty(CircuitMeshPart.prototype, 'component', {
    enumerable: true,
    get() { return this.part.component; }
});
