/**
* Available modes for editing
*/
EditingModes = [
    {
        desc: 'Zufällige Änderung',
        procSelected: function(place, circuit) {
            if (circuit.getElementAt(place.x, place.y, place.isHorizontal))
                circuit.clearGridLine(place.x, place.y, place.isHorizontal);
            else {
                var component = null;
                var flipped = false;
                switch (Math.floor(Math.random() * 4)) {
                    case 0:
                        component = new ModelConnection(circuit);
                        break;
                    case 1:
                        component = new ModelLightbulb(circuit);
                        break;
                    case 2:
                        component = new ModelSwitch(circuit);
                        component.on = (Math.random() < 0.5);
                        flipped = (Math.random() < 0.5);
                        break;
                    default:
                        component = new ModelMonocell(circuit);
                        flipped = (Math.random() < 0.5);
                        break;
                }
                circuit.addComponent(component, place.x, place.y, place.isHorizontal, flipped);
            }
        },
        procHover: function(place, circuit) {
            return 'ok';
        }
    },
    {
        desc: 'Löschen',
        title: 'Bauteil löschen',
        className: 'btn_delete',
        help: 'Ausgewähltes Schaltzeichen entfernen',
        procSelected: function(place, circuit) {
            if (circuit.getElementAt(place.x, place.y, place.isHorizontal))
                circuit.clearGridLine(place.x, place.y, place.isHorizontal);
        },
        procHover: function(place, circuit) {
            return circuit.getElementAt(place.x, place.y, place.isHorizontal) ? 'good' : 'bad';
        }
    },
    {
        desc: 'Ändern',
        title: 'Bauteilstatus verändern',
        className: 'btn_change',
        help: '',
        procSelected: function(place, circuit) {
            var part = circuit.getElementAt(place.x, place.y, place.isHorizontal);
            if (part && part.isConfigureable())
                part.startConfiguration()
        },
        procHover: function(place, circuit) {
            var part = circuit.getElementAt(place.x, place.y, place.isHorizontal);
            return (part && part.isConfigureable()) ? 'good' : 'bad';
        }
    },
    {
        desc: 'Umdrehen',
        title: 'Bauteilseiten vertauschen',
        className: 'btn_flip',
        procSelected: function(place, circuit) {
            var part = circuit.getElementAt(place.x, place.y, place.isHorizontal);
            if (part && !part.isSymmetric())
                part.isFlipped = !part.isFlipped;
        },
        procHover: function(place, circuit) {
            var part = circuit.getElementAt(place.x, place.y, place.isHorizontal);
            return (part && !part.isSymmetric()) ? 'good' : 'bad';
        }
    },
    /*{
        desc: 'Anschlüsse ergänzen/entfernen',
        title: 'Zusätzliche Bauteilanschlüsse ergänzen oder entfernen',
        className: 'btn_extraconnection',
        procSelected: function(place, circuit) {
            alert('Noch nicht programmiert');
        },
        procHover: function(place, circuit) {
            return 'bad';
        }
    },*/
    {
        desc: 'Simulation',
        className: 'btn_start',
        procSelected: function(place, circuit) {
            var part = circuit.getElementAt(place.x, place.y, place.isHorizontal);
            if (part && part.isInteractive())
                part.interactWith();
        },
        procHover: function(place, circuit) {
            var part = circuit.getElementAt(place.x, place.y, place.isHorizontal);
            return (part && part.isInteractive()) ? 'good' : 'bad';
        },
        procStart: function(circuit) {
            circuit.simulating = true;
        },
        procStop: function(circuit) {
            circuit.simulating = false;
        }
    }
];

[
    { name: 'Batterie', componentClass: ModelMonocell, className: 'btn_battery' },
    { name: 'Glühlämpchen', componentClass: ModelLightbulb, className: 'btn_lamp' },
    { name: 'Verbindung', componentClass: ModelConnection, className: 'btn_connection' },
    { name: 'Schmelzsicherung', componentClass: ModelFuse, className: 'btn_fuse' },
    { name: 'Schalter', componentClass: ModelSwitch, className: 'btn_switch' },
//    { name: 'Messgerät', componentClass: ModelMeter, className: 'btn_meter' },
    { name: 'Messgerät für Stromstärke', componentClass: ModelMeter, className: 'btn_amperemeter', parameter: true },
    { name: 'Messgerät für Spannung', componentClass: ModelMeter, className: 'btn_voltmeter', parameter: false }
].map(function(item) {
    var mode = { desc: item.name, title: item.name + ' einfügen' };
    const componentClass = item.componentClass;
    const parameter = item.parameter;
    mode.procHover = function(place, circuit) {
        var part = circuit.getElementAt(place.x, place.y, place.isHorizontal);
        return part ? ((part.component instanceof componentClass) ? 'bad' : 'ok') : 'good';
    };
    mode.procSelected = function(place, circuit, shiftKey, ctrlKey, altKey) {
        var part = circuit.getElementAt(place.x, place.y, place.isHorizontal);
        if (part)
            circuit.clearGridLine(place.x, place.y, place.isHorizontal);
        if (altKey)
            return;
        var part = circuit.addComponent(new componentClass(circuit, parameter), place.x, place.y, place.isHorizontal, componentClass.prevereFlipped ? !shiftKey : shiftKey);
        if (ctrlKey && part.isConfigureable())
            part.startConfiguration();
    };
    if (item.className)
        mode.className = item.className;
    EditingModes.push(mode);
});
