/**
* Creates a numberic id for each grid point
*/
function GridPointHasher(
    width       // Width of hole circuit or area (neccessary to calculate ids for grid points)
) {
    Object.defineProperty(this, 'width', { enumerable: true, writeable: false, value: width });
}

/** Width of hole circuit or area (neccessary to calculate ids for grid points */
GridPointHasher.prototype.width = 0;

/**
* Calculate an ID of grid point gridpoint
* @return Number    ID of grid point
*/
GridPointHasher.prototype.calcHash = function(
    gridpoint       // Object linke { x: …, y: … }
) {
    return gridpoint.x + gridpoint.y * this.width;
}

/**
* Creates a GridPointHasher instance for a specific ModelCircuit instance
* @return GridPointHasher       Hasher for circuit
*/
GridPointHasher.create = function(
    circuit     // ModelCircuit instance whoose grid points should be named
) {
    return new GridPointHasher(GridPointHasher.calcWidth(circuit));
}

/**
* Calc width of hole circuit (needed to calculate ids of grid points)
* @return Number        Width of hole circuit
*/
GridPointHasher.calcWidth = function(
    circuit     // ModelCircuit instance whoose grid points should be named
) {
    const size = circuit.getUsedGridArea();
    return Math.max(1, 1 + size.right - size.left);
}
