/**
* A horizontal or vertical lightbulb being part of a circuit
*/
function ModelLightbulb(
    circuit     // ModelCircuit instance this instance should belong to
) {
    ModelLightbulb.parent.call(this, circuit);
}
ModelLightbulb.parent = ModelComponent;
ModelLightbulb.prototype = Object.create(ModelLightbulb.parent.prototype);
ModelLightbulb.prototype.constructor = ModelLightbulb;

/**
* Create string representing component in serialized string
* @return String        String representing component (starting with corresponding letter registered in ModelComponent.serializingLetters) or false if component cannot be serialized
*/
ModelLightbulb.prototype.serialize = function() {
    return '*';
}

/**
* Which letter in serialized string correspondes to which child class of ModelComponent? Only lowercase is allowed, flippable components are represented by corresponding uppercase letter when flipped
*/
ModelComponent.serializingLetters['*'] = ModelLightbulb;

/**
* Create ModelLightbulb instance from serialized string s
* @return ModelLightbulb    Instance described by serialized string
*/
ModelLightbulb.fromSerialized = function(
    circuit,    // ModelCircuit instance this instance should belong to
    s           // Serialized string describing component
) {
    return new ModelLightbulb(circuit);
}

/** Resistance of lightbulb */
ModelLightbulb.prototype._resistance = 100;
Object.defineProperty(ModelLightbulb.prototype, 'resistance', {
    enumerable: true,
    get() { return this._resistance; },
    set(v) {
        if (!Number.isFinite(v) || (v == this._resistance))
            return;
        this._resistance = v;
        this.bubbleEvent('resistanceChanged');
    }
});

/** Current through lightbulb (calculated by simulation) */
ModelLightbulb.prototype._current = undefined;
Object.defineProperty(ModelLightbulb.prototype, 'current', {
    enumerable: true,
    get() { return this._current; },
    set(v) {
        if (v == this._current)
            return;
        this._current = v;
//        this.bubbleEvent('currentChanged');
    }
});

/** Is lightbulb turned on? */
Object.defineProperty(ModelLightbulb.prototype, 'isOn', {
    enumerable: true,
    get() { return (Number.isFinite(this._current) && this._current); }
});

/**
* Get present constant resistance of this component (if any)
* @return Number    Resistance in ohms (can be infinity)
*/
ModelLightbulb.prototype.getConstraintResistance = function() {
    return this.resistance;
}

/**
* Set current simulation status (e. g. current)
* @return undefined
*/
ModelLightbulb.prototype.setSimulationStatus = function(
    current         // Current through component (undefined → no simulation; Infinity → short circuit)
) {
    this.current = current;
}
