/**
* A horizontal or vertical lightbulb being part of a circuit
*/
function ModelMonocell(
    circuit     // ModelCircuit instance this instance should belong to
) {
    ModelMonocell.parent.call(this, circuit);
}
ModelMonocell.parent = ModelComponent;
ModelMonocell.prototype = Object.create(ModelMonocell.parent.prototype);
ModelMonocell.prototype.constructor = ModelMonocell;

/** Prefere adding flipped components */
ModelMonocell.prevereFlipped = true;

/** Voltage of monocell */
ModelMonocell.prototype._voltage = 1.5;
Object.defineProperty(ModelMonocell.prototype, 'voltage', {
    enumerable: true,
    get() { return this._voltage; },
    set(v) {
        if (!Number.isFinite(v) || (v == this._voltage))
            return;
        this._voltage = v;
        this.bubbleEvent('voltageChanged');
    }
});

/** Is component short circuited? */
ModelMonocell.prototype._shortCircuited = false;
Object.defineProperty(ModelMonocell.prototype, 'shortCircuited', {
    enumerable: true,
    get() { return this._shortCircuited; },
    set(v) {
        const realValue = (v ? true : false);
        if (realValue == this._shortCircuited)
            return;
        this._shortCircuited = realValue;
//        this.bubbleEvent('voltageChanged');
    }
});

/**
* Get present constant voltage generated by this component (if any)
* @return Number    Voltage in volts (0 if this component does not generate a voltage); positive number means secondary connector has a higher potential than primary connector
*/
ModelMonocell.prototype.getConstraintVoltage = function() {
    return -this.voltage;
}

/**
* Returns whether this component is symmetrical
* @return Boolean   Does the orientation of this component *not* make any difference?
*/
ModelMonocell.prototype.isSymmetric = function() {
    return false;
}

/**
* Returns whether both connections are not electrical exchangeable
* @return Boolean   Are there different kinds of connectors?
*/
ModelMonocell.prototype.isDifferentConnectors = function() {
    return true;
}

/**
* Create string representing component in serialized string
* @return String        String representing component (starting with corresponding letter registered in ModelComponent.serializingLetters) or false if component cannot be serialized
*/
ModelMonocell.prototype.serialize = function() {
    return 'b';
}

/**
* Which letter in serialized string correspondes to which child class of ModelComponent? Only lowercase is allowed, flippable components are represented by corresponding uppercase letter when flipped
*/
ModelComponent.serializingLetters['b'] = ModelMonocell;

/**
* Create ModelMonocell instance from serialized string s
* @return ModelMonocell     Instance described by serialized string
*/
ModelMonocell.fromSerialized = function(
    circuit,    // ModelCircuit instance this instance should belong to
    s           // Serialized string describing component
) {
    return new ModelMonocell(circuit);
}

/**
* Set current simulation status (e. g. current)
* @return undefined
*/
ModelMonocell.prototype.setSimulationStatus = function(
    current         // Current through component (undefined → no simulation; Infinity → short circuit)
) {
    this.shortCircuited = (Math.abs(current) == Infinity);
}
