/**
* Class managing all event listeners of its parent distinguishing different events
*/
function MultiListenerManager(
    parent      // Object whoose events should be managed
) {
    this._listener = {};
    this._parent = parent;
}

/**
* Add a event listener for event type what
* @return undefined
*/
MultiListenerManager.prototype.addEventListener = function(
    what,       // Type of event (true means event listener for all events)
    listener    // Event listener to call whenever event of type what occures
) {
    if ((typeof what != 'string') && !(what instanceof String))
        what = '';
    if (this._listener[what] instanceof Array)
        this._listener[what].push(listener);
    else
        this._listener[what] = [ listener ];
}

/**
* Remove previously added event listener
* @return undefined
*/
MultiListenerManager.prototype.removeEventListener = function(
    what,       // Type of event
    listener    // Event listener not to call any longer
) {
    if (this._listener[what] instanceof Array)
        this._listener[what] = this._listener[what].filter(function(fkt) { return (fkt != listener); });
}

/** If true, no event listeners will be called */
MultiListenerManager.prototype.muted = false;

/**
* Fire all event listeners internaly beeing registered as type what with arguments args
* @return undefined
*/
MultiListenerManager.prototype._fireEvent = function(
    type,       // Type of event
    args        // Parameters for event listener calls
) {
    if (!(this._listener[type] instanceof Array))
        return;
    var parent = self._parent;
    this._listener[type].map(
        function (listener) {
            if (listener instanceof Function)
                listener.apply(parent, args);
        }
    );
}

/**
* Fire all corresponding event listeners
* @return undefined
*/
MultiListenerManager.prototype.fireEvent = function(
    what        // Type of event
    // All further arguments are parameters of event listeners
) {
    if (this.muted)
        return;
    var args = [].slice.call(arguments, 1);
    this._fireEvent(what, args);
    this._fireEvent('', arguments);
}
