/**
* Submenu for saving a circuit as an image
*/
function SaveForm(
    objBtnBar,      // Responsible BtnBar instance
    circuit,        // ModelCircuit instance containing data of actual circuit
    scale
) {
    const self = this;
    this.objBtnBar = objBtnBar;
    this.circuit = circuit;
    const objBubble = objBtnBar.showBubble();

    var submenu = new BtnBar(objBubble.node, true, objBubble, true);
    const downloadNormal = createHtml('a', createHtml('li', submenu.node, {class: 'btn_save'}), {
        href: '#',
        download: 'schaltplan.svg'
    }, 'Schaltplan speichern');
    const downloadWithGrid = createHtml('a', createHtml('li', submenu.node, {class: 'btn_save'}), {
        href: '#',
        download: 'schaltplan.svg'
    }, 'Mit Gitterlinien speichern');
    submenu.add([
        { label: 'Abbrechen', className: 'btn_close', title: 'Dieses Menü schließen' }
    ]);

    this._urls2revoce = [];
    objBubble.onclose = (() => this._urls2revoce.forEach(url => window.URL.revokeObjectURL(url)));
    this.createDownloadUrl(downloadNormal, false, scale);
    this.createDownloadUrl(downloadWithGrid, true, scale);

    downloadNormal.focus();
}

/** Responsible BtnBar instance */
SaveForm.prototype.objBtnBar = null;

/** ModelCircuit instance containing data of actual circuit */
SaveForm.prototype.circuit = null;

/** Array of urls to revoce on bubble closeing */
SaveForm.prototype._urls2revoce = [];

/**
* Update href attribute of link nodeA to refere to a svg image of the recent circuit
* @return undefined
*/
SaveForm.prototype.createDownloadUrl = function(
    nodeA,      // Download link (DOM node)
    boolGrid,   // Show grid?
    scale       // Scale for rendering (in local units)
) {
    const self = this;
    const oReq = new XMLHttpRequest();
    oReq.addEventListener("load", function() {
        const doc = oReq.responseXML;
        const builder = new ViewCircuitBuilder(self.circuit, doc, scale);
        builder.addData();
        builder.addCircuitParts();
        builder.addDots();
        if (boolGrid) builder.addGrid();
        [...builder.node.childNodes].forEach(child => doc.documentElement.appendChild(doc.importNode(child, true)));
        [...builder.node.attributes].forEach( attr => { doc.documentElement.setAttributeNS(attr.namespaceURI, attr.nodeName, attr.nodeValue) });
        const url = window.URL.createObjectURL(new Blob([new XMLSerializer().serializeToString(doc)], {type: 'image/svg+xml'}));
        nodeA.href = url;
        self._urls2revoce.push(url);
    });
    oReq.open("GET", 'data:image/svg+xml;base64,PD94bWwgdmVyc2lvbj0iMS4wIiBlbmNvZGluZz0iVVRGLTgiPz4KPHN2ZyB3aWR0aD0iMTBtbSIgaGVpZ2h0PSIxMG1tIiB2ZXJzaW9uPSIxLjEiIHZpZXdCb3g9IjAgMCAxMCAxMCIgeG1sbnM9Imh0dHA6Ly93d3cudzMub3JnLzIwMDAvc3ZnIj48L3N2Zz4K');
    oReq.send();
}
