/**
* Class for converting internal coordinates to SVG local units
*/
function ViewCircuitDimensions(
    minInternalX,       // Minimal internal x coordinate respecting image padding
    minInternalY,       // Minimal internal y coordinate respecting image padding
    maxInternalX,       // Maximal internal x coordinate respecting image padding
    maxInternalY,       // Maximal internal y coordinate respecting image padding
    scale               // Number of SVG local units per internal unit
) {
    this.minInternalX = minInternalX;
    this.minInternalY = minInternalY;
    this.maxInternalX = maxInternalX;
    this.maxInternalY = maxInternalY;
    this.scale = scale;
}

/** Minimal internal x coordinate respecting image padding */
ViewCircuitDimensions.prototype.minInternalX = 0;

/** Minimal internal y coordinate respecting image padding */
ViewCircuitDimensions.prototype.minInternalY = 0;

/** Maximal internal x coordinate respecting image padding */
ViewCircuitDimensions.prototype.maxInternalX = 1;

/** Maximal internal y coordinate respecting image padding */
ViewCircuitDimensions.prototype.maxInternalY = 1;

/** Number of SVG local units per internal unit */
ViewCircuitDimensions.prototype.scale = 1;

/**
* Convert internal length to SVG local units
* @return Number    Corresponding length in SVG local units
*/
ViewCircuitDimensions.prototype.internal2local = function(
    internalX       // X coordinate in local units
) {
    return internalX * this.scale;
}

/**
* Convert internal x coordinate to SVG local units
* @return Number    Corresponding x coordinate in SVG local units
*/
ViewCircuitDimensions.prototype.internal2localX = function(
    internalX       // X coordinate in local units
) {
    return (internalX - this.minInternalX) * this.scale;
}

/**
* Convert internal y coordinate to SVG local units
* @return Number    Corresponding y coordinate in SVG local units
*/
ViewCircuitDimensions.prototype.internal2localY = function(
    internalY       // Y coordinate in local units
) {
    return (internalY - this.minInternalY) * this.scale;
}

/** Minimal x coordinate respecting image padding in SVG local units */
Object.defineProperty(ViewCircuitDimensions.prototype, 'minLocalX', {
    enumerable: true,
    get() { return this.internal2localX(this.minInternalX); }
});

/** Minimal y coordinate respecting image padding in SVG local units */
Object.defineProperty(ViewCircuitDimensions.prototype, 'minLocalY', {
    enumerable: true,
    get() { return this.internal2localY(this.minInternalY); }
});

/** Maximal x coordinate respecting image padding in SVG local units */
Object.defineProperty(ViewCircuitDimensions.prototype, 'maxLocalX', {
    enumerable: true,
    get() { return this.internal2localX(this.maxInternalX); }
});

/** Maximal y coordinate respecting image padding in SVG local units */
Object.defineProperty(ViewCircuitDimensions.prototype, 'maxLocalY', {
    enumerable: true,
    get() { return this.internal2localY(this.maxInternalY); }
});

/** Total image width in SVG local units */
Object.defineProperty(ViewCircuitDimensions.prototype, 'localWidth', {
    enumerable: true,
    get() { return Math.abs(this.maxLocalX - this.minLocalX); }
});

/** Total image height in SVG local units */
Object.defineProperty(ViewCircuitDimensions.prototype, 'localHeight', {
    enumerable: true,
    get() { return Math.abs(this.maxLocalY - this.minLocalY); }
});
