/**
* Draw fuse in SVG
* @return boolean       Did this function render circuitpart?
*/
function renderFuse(
    view,
    dimensions,
    circuitpart     // ModelCircuitPart instance to eventually render
) {
    if (!(circuitpart.component instanceof ModelFuse))
        return false;
    var place = circuitpart.getUsedGridArea();
    var group = view.getLayer(ViewCircuit.LAYER_COMPONENTS).addGroup();
    if (circuitpart.component.isBlown) {
        group.addElement('line', {
            x1: dimensions.internal2localX(place.left),
            x2: dimensions.internal2localX(place.left + (place.right - place.left) * (1 - renderFuse.gapLength) / 2),
            y1: dimensions.internal2localY(place.top),
            y2: dimensions.internal2localY(place.top + (place.bottom - place.top) * (1 - renderFuse.gapLength) / 2)
        });
        group.addElement('line', {
            x1: dimensions.internal2localX(place.right - (place.right - place.left) * (1 - renderFuse.gapLength) / 2),
            x2: dimensions.internal2localX(place.right),
            y1: dimensions.internal2localY(place.bottom - (place.bottom - place.top) * (1 - renderFuse.gapLength) / 2),
            y2: dimensions.internal2localY(place.bottom)
        });
    } else
        group.addElement('line', {
            x1: dimensions.internal2localX(place.left),
            x2: dimensions.internal2localX(place.right),
            y1: dimensions.internal2localY(place.top),
            y2: dimensions.internal2localY(place.bottom)
        });
    const isHorizontal = circuitpart.isHorizontal;
    group.addElement('rect', {
        x: dimensions.internal2localX(place.left + (isHorizontal ? 0.2 : -0.1)),
        y: dimensions.internal2localY(place.top + (isHorizontal ? -0.1 : 0.2)),
        width: dimensions.internal2localX(isHorizontal ? 0.6 : 0.2) - dimensions.internal2localX(0),
        height: dimensions.internal2localY(isHorizontal ? 0.2 : 0.6) - dimensions.internal2localY(0)
    });
    return true;
}

/** Length of gap for blown fuses in local units */
renderFuse.gapLength = 0.3;
