/**
* Draw lightbulb in SVG
* @return boolean       Did this function render circuitpart?
*/
function renderLightbulb(
    view,
    dimensions,
    circuitpart     // ModelCircuitPart instance to eventually render
) {
    if (!(circuitpart.component instanceof ModelLightbulb))
        return false;
    var place = circuitpart.getUsedGridArea();
    var group = view.getLayer(ViewCircuit.LAYER_COMPONENTS).addGroup();
    group.addElement('line', {
        x1: dimensions.internal2localX(place.left),
        x2: dimensions.internal2localX(place.right),
        y1: dimensions.internal2localY(place.top),
        y2: dimensions.internal2localY(place.bottom)
    });
    var cx = place.left + (circuitpart.isHorizontal ? 0.5 : 0);
    var cy = place.top + (circuitpart.isHorizontal ? 0 : 0.5);
    group.addElement('circle', {
        'cx': dimensions.internal2localX(cx),
        'cy': dimensions.internal2localY(cy),
        'r': dimensions.internal2local(renderLightbulb.radius),
        'style': 'fill:#' + (circuitpart.component.isOn ? 'edd400' : 'fff')
    });
    var d = renderLightbulb.radius / Math.sqrt(2);
    group.addElement('line', {
        x1: dimensions.internal2localX(cx - d),
        y1: dimensions.internal2localY(cy + d),
        x2: dimensions.internal2localX(cx + d),
        y2: dimensions.internal2localY(cy - d)
    });
    group.addElement('line', {
        x1: dimensions.internal2localX(cx - d),
        y1: dimensions.internal2localY(cy - d),
        x2: dimensions.internal2localX(cx + d),
        y2: dimensions.internal2localY(cy + d)
    });
    return true;
}

/** Radius */
renderLightbulb.radius = 0.2;
