/**
* Draw meter for voltage or current intensity in SVG
* @return boolean       Did this function render circuitpart?
*/
function renderMeter(
    view,
    dimensions,
    circuitpart     // ModelCircuitPart instance to eventually render
) {
    if (!(circuitpart.component instanceof ModelMeter))
        return false;
    var place = circuitpart.getUsedGridArea();
    var group = view.getLayer(ViewCircuit.LAYER_COMPONENTS).addGroup();
    group.addElement('line', {
        x1: dimensions.internal2localX(place.left),
        x2: dimensions.internal2localX(place.right),
        y1: dimensions.internal2localY(place.top),
        y2: dimensions.internal2localY(place.bottom)
    });
    var cx = place.left + (circuitpart.isHorizontal ? 0.5 : 0);
    var cy = place.top + (circuitpart.isHorizontal ? 0 : 0.5);
    group.addElement('circle', {
        'cx': dimensions.internal2localX(cx),
        'cy': dimensions.internal2localY(cy),
        'r': dimensions.internal2local(renderLightbulb.radius),
        'style': 'fill:#fff'
    });
    if (circuitpart.component.measureCurrent)
        renderMeter.renderLetterA(group, dimensions, cx, cy);
    else
        renderMeter.renderLetterV(group, dimensions, cx, cy);
if (circuitpart.component.measured !== undefined)
console.log('Gemessen:', circuitpart.component.measured + (circuitpart.component.measureCurrent ? ' A' : ' V'))
    return true;
}

/** Radius */
renderMeter.radius = 0.2;

/**
* Add letter 'A' to layer group
* @return undefined
*/
renderMeter.renderLetterV = function(
    group,          // ViewCircuitGroup for output
    dimensions,
    cx,             // Horizontal position of center of letter
    cy              // Vertical position of center of letter
) {
    const letterRadius = renderMeter.radius - renderMeter.letterDistance;
    const dStartX = letterRadius * Math.sin(renderMeter.bottomAngle);
    const dStartY = letterRadius * Math.cos(renderMeter.bottomAngle);
    group.addElement('path', {
        d: 'M' + dimensions.internal2localX(cx - dStartX) + ' ' + dimensions.internal2localY(cy - dStartY) +
           'L' + dimensions.internal2localX(cx) + ' ' + dimensions.internal2localY(cy + letterRadius) +
           ' ' + dimensions.internal2localX(cx + dStartX) + ' ' + dimensions.internal2localY(cy - dStartY)
    });
}

/** Distance between circle and letter */
renderMeter.letterDistance = 0.08;

/** Angle between V's legs at the bottom */
renderMeter.bottomAngle = 47 * Math.PI / 180;

/**
* Add letter 'A' to layer group
* @return undefined
*/
renderMeter.renderLetterA = function(
    group,          // ViewCircuitGroup for output
    dimensions,
    cx,             // Horizontal position of center of letter
    cy              // Vertical position of center of letter
) {
    const letterRadius = renderMeter.radius - renderMeter.letterDistance;
    const dStartX = letterRadius * Math.sin(renderMeter.topAngle);
    const dStartY = letterRadius * Math.cos(renderMeter.topAngle);
    group.addElement('path', {
        d: 'M' + dimensions.internal2localX(cx - dStartX) + ' ' + dimensions.internal2localY(cy + dStartY) +
           'L' + dimensions.internal2localX(cx) + ' ' + dimensions.internal2localY(cy - letterRadius) +
           ' ' + dimensions.internal2localX(cx + dStartX) + ' ' + dimensions.internal2localY(cy + dStartY)
    });
    group.addElement('line', {
        x1: dimensions.internal2localX(cx - dStartX / 2),
        y1: dimensions.internal2localY(cy),
        x2: dimensions.internal2localX(cx + dStartX / 2),
        y2: dimensions.internal2localY(cy)
    });
}

/** Angle between A's legs at the top */
renderMeter.topAngle = 45 * Math.PI / 180;
