/**
* Draw switch in SVG
* @return boolean       Did this function render circuitpart?
*/
function renderSwitch(
    view,           // SVG (ViewCircuit instance) used for rendering
    dimensions,     // ViewCircuitDimensions instance providing messurements
    circuitpart     // ModelCircuitPart instance to eventually render
) {
    if (!(circuitpart.component instanceof ModelSwitch))
        return false;
    var place = circuitpart.getUsedGridArea();
    var minX = circuitpart.isFlipped ? place.right : place.left;
    var maxX = circuitpart.isFlipped ? place.left : place.right;
    var minY = circuitpart.isFlipped ? place.bottom : place.top;
    var maxY = circuitpart.isFlipped ? place.top : place.bottom;

    var abstand = (1 - renderSwitch.switchLength) / 2;
    var cx1 = (1 - abstand) * minX + abstand * maxX;
    var cy1 = (1 - abstand) * minY + abstand * maxY;
    var cx2 = abstand * minX + (1 - abstand) * maxX;
    var cy2 = abstand * minY + (1 - abstand) * maxY;

    var schraeglaenge = renderSwitch.additionalLength * renderDot.radius + renderSwitch.switchLength;
    var tan = (circuitpart.component.on ? 1 : renderSwitch.offHeight) * renderDot.radius / renderSwitch.switchLength;
    var sqrt = Math.sqrt(tan * tan + 1);
    var d_parallel = schraeglaenge / sqrt;
    var d_senkrecht = -tan * d_parallel;

    var group = view.getLayer(ViewCircuit.LAYER_COMPONENTS).addGroup();
    group.addElement('path', {
        d: 'M ' + dimensions.internal2localX(minX) + ' ' + dimensions.internal2localY(minY) + ' L ' + dimensions.internal2localX(cx1) + ' ' + dimensions.internal2localY(cy1) + ' ' +dimensions.internal2localX(cx1 + d_parallel * (maxX - minX) + d_senkrecht * (maxY - minY)) + ' ' + dimensions.internal2localY(cy1 + d_senkrecht * (maxX - minX) + d_parallel * (maxY - minY))
    });
    group.addElement('line', {
        x1: dimensions.internal2localX(cx2),
        y1: dimensions.internal2localY(cy2),
        x2: dimensions.internal2localX(maxX),
        y2: dimensions.internal2localY(maxY)
    });
    renderDot(view, dimensions, cx1, cy1, false);
    renderDot(view, dimensions, cx2, cy2, true);
    return true;
}

/** Length of switch in internal units */
renderSwitch.switchLength = 0.3;

/** Additional length of switch over real distance as renderDot.radius factor */
renderSwitch.additionalLength = 1.5;

/** Factor for height of free connector over connection dot as renderDot.radius factor */
renderSwitch.offHeight = 3;
